==> linkfuture.core-1.0.3-sources.jar: LinkFuture/Core/MemoryManager/MemoryFactory.java <==
package LinkFuture.Core.MemoryManager;

import LinkFuture.Core.MemoryManager.Meta.MemoryCacheMetaInfo;
import LinkFuture.Core.MemoryManager.Meta.MemoryCacheSettingInfo;
import LinkFuture.Core.MemoryManager.Meta.MemoryCacheSettingListInfo;
import LinkFuture.Core.MemoryManager.Meta.MemoryCacheSolution;
import LinkFuture.Core.MemoryManager.Redis.RedisMemoryController;
import LinkFuture.Core.MemoryManager.StaticMemoryCache.StaticMemoryCacheController;
import LinkFuture.Core.Utility;
import LinkFuture.Init.ConfigurationManager.ConfigurationController;
import LinkFuture.Init.Debugger;
import LinkFuture.Init.Extensions.PathExtension;
import LinkFuture.Init.Extensions.StringExtension;

/**
 * Created by Cyokin on
 * 12/16/2014.
 */
public class MemoryFactory {
    public static final MemoryCacheSettingListInfo ConfigurationMeta = Read();
    private static MemoryCacheSettingListInfo Read() {
        try {
            String filePath = PathExtension.getConfigFilePath(ConfigurationController.AppSettings("MemoryCatchFilePath"));
            return Utility.fromXml(LinkFuture.Init.Utility.getStringFromFile(filePath), MemoryCacheSettingListInfo.class);
        }
        catch (Exception ex)
        {
            Debugger.LogFactory.error("Init memory setting failed",ex);
            throw new RuntimeException("Init memory setting failed, due to", ex);
        }
    }

    public static MemoryCacheMetaInfo FindMemoryCache(String cacheSettingName){
        if(ConfigurationMeta==null || !ConfigurationMeta.SettingList.containsKey(cacheSettingName))
        {
            return null;
        }
        MemoryCacheSettingInfo setting =  ConfigurationMeta.SettingList.get(cacheSettingName);
        MemoryCacheMetaInfo meta = new MemoryCacheMetaInfo();
        meta.Duration =  setting.Duration;
        meta.CacheSettingName = setting.CacheSettingName;
        meta.AutoRefresh = setting.AutoRefresh;
        meta.Enable = setting.Enable;
        meta.CacheType = setting.CacheType;
        return meta;
    }

    public static IMemoryController FindMemoryCacheAdapter(MemoryCacheSettingInfo setting){
        if(setting.Solution== MemoryCacheSolution.Redis && !StringExtension.IsNullOrEmpty(setting.RedisUrl))
        {
            return new RedisMemoryController(setting.RedisUrl);
        }
        return new StaticMemoryCacheController();
    }
}

==> linkfuture.core-2.1.0-sources.jar: LinkFuture/Core/MemoryManager/MemoryFactory.java <==
package LinkFuture.Core.MemoryManager;

import LinkFuture.Core.MemoryManager.Meta.MemoryCacheMetaInfo;
import LinkFuture.Core.MemoryManager.Meta.MemoryCacheSettingInfo;
import LinkFuture.Core.MemoryManager.Meta.MemoryCacheSettingListInfo;
import LinkFuture.Core.MemoryManager.Meta.MemoryCacheSolution;
import LinkFuture.Core.MemoryManager.Redis.RedisMemoryController;
import LinkFuture.Core.MemoryManager.StaticMemoryCache.StaticMemoryCacheController;
import LinkFuture.Core.Utility;
import LinkFuture.Init.ConfigurationManager.ConfigurationController;
import LinkFuture.Init.Debugger;
import LinkFuture.Init.Extensions.StringExtension;

/**
 * Created by Cyokin on
 * 12/16/2014.
 */
public class MemoryFactory {
    public static final MemoryCacheSettingListInfo ConfigurationMeta = Read();
    private static MemoryCacheSettingListInfo Read() {
        try {
            return Utility.fromXml(LinkFuture.Init.Utility.getStringFromFile(ConfigurationController.AppSettings("MemoryCatchFilePath")), MemoryCacheSettingListInfo.class);
        }
        catch (Exception ex)
        {
            Debugger.LogFactory.error("Init memory setting failed",ex);
            throw new RuntimeException("Init memory setting failed, due to", ex);
        }
    }

    public static MemoryCacheMetaInfo FindMemoryCache(String cacheSettingName){
        if(ConfigurationMeta==null || !ConfigurationMeta.SettingList.containsKey(cacheSettingName))
        {
            return null;
        }
        MemoryCacheSettingInfo setting =  ConfigurationMeta.SettingList.get(cacheSettingName);
        MemoryCacheMetaInfo meta = new MemoryCacheMetaInfo();
        meta.Duration =  setting.Duration;
        meta.CacheSettingName = setting.CacheSettingName;
        meta.AutoRefresh = setting.AutoRefresh;
        meta.Enable = setting.Enable;
        meta.CacheType = setting.CacheType;
        return meta;
    }

    public static IMemoryController FindMemoryCacheAdapter(MemoryCacheSettingInfo setting){
        if(setting.Solution== MemoryCacheSolution.Redis && !StringExtension.IsNullOrEmpty(setting.RedisUrl))
        {
            return new RedisMemoryController(setting.RedisUrl);
        }
        return new StaticMemoryCacheController();
    }
}
